@@ -14,14 +14,27 @@ from django.contrib import admin
 from django_object_actions import DjangoObjectActions
 import subprocess
 
-# todo: active directory sync users
-# todo: fix the sig structure
+from pcaps.admin import verify_legal_pcap
+
+
+# todo: fix the sig structure: assitent needed
+# todo: upload unmanaged rule file
 
 class SnortRuleAdminForm(forms.ModelForm):
     class Meta:
         model = SnortRule
         fields = "__all__"
 
+    def clean_group(self):
+        return self.current_user.groups.name or "unassinged group"
+
+    def clean_user(self):
+        return getattr(self.current_user, self.current_user.USERNAME_FIELD)
+
+    def clean_date(self):
+        return self.cleaned_data["date"]
+
+
     def clean_type(self):
         if not dict(types_list).get(self.cleaned_data.get("type")):
             raise forms.ValidationError("cant find type, did you forgot it? or forgot to add type to db")
@@ -46,7 +59,8 @@ class SnortRuleAdminForm(forms.ModelForm):
                                                                                                    main_doc="0",
                                                                                                    cur_date=time.time(),
                                                                                                    sig_ref="0",
-                                                                                                   sig_desc="Test")
+                                                                                                   sig_desc="Test",
+                                                                                                   sid=self.current_user.id)
                     parser = Parser(rule_template)
                     parser.parse_header()
                     parser.parse_options()
@@ -67,6 +81,7 @@ class SnortRuleAdminForm(forms.ModelForm):
         return self.cleaned_data["location"]
 
     def clean_pcap_validation(self):
+        # return self.cleaned_data.get("pcap_validation")
         if not self.cleaned_data.get("pcap_validation"):
             raise forms.ValidationError("pcap validateion cannot be empty, please find a pcap that aggre with your rule")
         cur_rule = SnortRule()
@@ -86,8 +101,9 @@ class SnortRuleAdminForm(forms.ModelForm):
 
 def validate_pcap_snort(pcaps, rule):
     rule_template = snort_type_to_template[dict(types_list)[rule.type]]().get_rule(rule.group, sig_name=rule.name, sig_content=rule.content, writer_team=rule.group, sig_writer=rule.user, main_doc=rule.main_ref, cur_date=time.time(), sig_ref=rule.request_ref, sig_desc=rule.description)
+    stdout = b""
     if not rule.location:
-        import re, unicodedata
+        import re
         rule.location = re.sub(r'[-\s]+', '-',re.sub(r'[^\w\s-]', '',
                                  rule.name)
                           .strip()
@@ -95,9 +111,10 @@ def validate_pcap_snort(pcaps, rule):
 
     with open(rule.location + ".tmp", "w") as rule_file:
         rule_file.write(rule_template)
+    failed = True
     for pcap in pcaps:
         try:
-            if not verify_leagal_pcap("/app/{pcap.pcap_file}"):
+            if not verify_legal_pcap("/app/{pcap.pcap_file}"):
                 raise Exception(f"illegal pcap file")
             if not os.path.exists(f"/app/{pcap.pcap_file}"):
                 raise Exception(f"cant find file /app/{pcap.pcap_file}")
@@ -112,52 +129,48 @@ def validate_pcap_snort(pcaps, rule):
                 raise forms.ValidationError(stderr + "<br>----------" + stdout.decode())
         except Exception as e:
             raise forms.ValidationError(f"could not validate rule on {pcap.pcap_file}: {e}")
-        return stdout
+    if failed:
+        raise Exception("no rules was chosen")
+    return stdout
 
 
-def verify_leagal_pcap(filename):
-    import dpkt
-    counter = 0
-
-    for ts, pkt in dpkt.pcap.Reader(open(filename, 'br')):
-
-        counter += 1
-        eth = dpkt.ethernet.Ethernet(pkt)
-        if eth.type != dpkt.ethernet.ETH_TYPE_IP:
-            continue
-
-    if not counter:
-        return False
-    return True
-
 @admin.register(SnortRule)
 class SnortRuleAdmin(DjangoObjectActions, admin.ModelAdmin):
-    change_actions = ('validate',)
-    changelist_actions = ('validate',)
-
+    # change_actions = ('validate',)
+    # changelist_actions = ('validate',)
+    filter_horizontal = ('pcap_validation',)
     list_display = ("name", "type", "description", "date", "main_ref")
     search_fields = ("name", "description", "content", "template", "type", "main_ref", "request_ref")
     form = SnortRuleAdminForm
-
+    def get_form(self, request, *args, ** kwargs):
+        form = super(SnortRuleAdmin, self).get_form(request, **kwargs)
+        form.current_user = request.user
+        return form
 
     def validate(self, request, obj:SnortRule):
-        # todo test saved rule vs pcap
         error = ""
         stdout = ""
         status = messages.ERROR
         try:
-            stdout = validate_pcap_snort(obj.pcap_validation.all(), obj)
-            stdout = stdout.decode().replace('\n', '<br>')
-            status = messages.SUCCESS
-            message = "The {name} “{obj}” run validation on {pcap} with results:<br>"+ f"{stdout}"
-        except Exception as e:
-            error = e
-        if os.name =="nt":
+            snort_item = obj.first()
+        except:
+            snort_item = obj
+        if os.name == "nt":
             error = f"cannot validate on windows"
+            status = messages.ERROR
+        else:
+            try:
+                stdout = validate_pcap_snort(snort_item.pcap_validation.all(), obj)
+
+                stdout = stdout.decode().replace('\n', '<br>')
+                status = messages.SUCCESS
+                message = "The {name} “{obj}” run validation on {pcap} with results:<br>"+ f"{stdout}"
+            except Exception as e:
+                error = e
         if error:
             message = "The {name} “{obj}” failed validation on {pcap} due to ERROR:<b>{err}</b>"
         msg_dict = {
-            "name": obj._meta.verbose_name,
+            "name": snort_item._meta.verbose_name,
             "obj": format_html('<a href="{}">{}</a>', urlquote(request.path), obj),
             "pcap": "all",
             "err": error
@@ -166,11 +179,11 @@ class SnortRuleAdmin(DjangoObjectActions, admin.ModelAdmin):
             gettext(message), **msg_dict
         )
         self.message_user(request, msg, status)
-        return self.change_view(request, str(obj.id))
-    validate.label = "validate on pcaps"  # optional
-    validate.color = "green"
+        return self.change_view(request, str(snort_item.id))
+    # validate.label = "validate on pcaps"  # optional
+    # validate.color = "green"
     readonly_fields = ('location', "user")
-    validate.short_description = "test rule on pcaps"  # optional
+    # validate.short_description = "test rule on pcaps"  # optional
 
 
 
